/*
 * gtkmovefilter.h
 *
 * by Joern Thyssen <jthyssen@dk.ibm.com>, 2002
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of version 3 or later of the GNU General Public License as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: gtkmovefilter.h,v 1.7 2013/06/16 02:16:15 mdpetch Exp $
 */

#ifndef GTKMOVEFILTER_H
#define GTKMOVEFILTER_H

extern GtkWidget *MoveFilterWidget(movefilter * pmf, int *pfOK, GCallback pfChanged, gpointer userdata);

extern void


SetMovefilterCommands(const char *sz,
                      movefilter aamfNew[MAX_FILTER_PLIES][MAX_FILTER_PLIES],
                      movefilter aamfOld[MAX_FILTER_PLIES][MAX_FILTER_PLIES]);

extern void
 MoveFilterSetPredefined(GtkWidget * pwMoveFilter, const int i);

#endif                          /* GTKMOVEFILTER_H */
